﻿using System.Windows.Controls;

using System.Collections.Generic;

using Jp.Co.Atmarkit.Sample.Dao;
using Jp.Co.Atmarkit.Sample.Dto;
using Jp.Co.Atmarkit.Sample.Entity;
using Jp.Co.Atmarkit.Sample.Event;
using Jp.Co.Atmarkit.Sample.Utils;
using System.Collections.ObjectModel;

namespace Jp.Co.Atmarkit.Sample.Web
{
    /// <summary>
    /// サンプルアプリケーションのコードビハインドです。
    /// </summary>
    public partial class Sample : UserControl
    {
        /// <summary>ユーザーDAOです。</summary>
        private UserDao Dao;

        /// <summary>
        /// コンストラクタです。
        /// </summary>
        public Sample()
        {
            InitializeComponent();

            // ユーザー一覧データグリッドの行選択変更イベントハンドラを指定します。
            UserListDataGrid.SelectionChanged += new SelectionChangedEventHandler(UserListDataGrid_SelectionChanged);

            // ユーザー一覧を取得します。
            GetUserList();
        }

        /// <summary>
        /// ユーザー一覧を取得します。
        /// </summary>
        private void GetUserList()
        {
            // 空のリクエストDTOを作成します。
            // ユーザー一覧取得には特に取得条件は不要なのでリクエストDTOは空です。
            UserRequestDto dto = new UserRequestDto();
            
            // ユーザー一覧を取得します。
            Dao = new UserDao();
            Dao.Result += new UserDao.ResultEventHandler(GetUserListResultHandler);
            Dao.GetUserList(dto);
        }

        /// <summary>
        /// ユーザー一覧取得の結果イベントハンドラです。
        /// </summary>
        /// <param name="sender">イベントのソースです。</param>
        /// <param name="e">イベント データを格納している EventArgsです。</param>
        private void GetUserListResultHandler(object sender, ResultEventArgs e)
        {
            DebugUtil.Log("Page#GetUserListResultHandler");

            // レスポンスDTOからユーザー一覧を取得します。
            UserResponseDto dto = (UserResponseDto)e.Result;
            
            // ユーザー一覧を画面のユーザー一覧に設定します。
            this.UserListDataGrid.ItemsSource = dto.UserList;
        }

        /// <summary>
        /// ユーザー一覧データグリッドの行選択変更イベントハンドラです。
        /// </summary>
        /// <param name="sender">選択行です。</param>
        /// <param name="e">イベント データを格納している EventArgsです。</param>
        private void UserListDataGrid_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            DebugUtil.Log("Page#UserListDataGrid_SelectionChanged");

            // 選択された行を取得します。
            User selectedUser = (User) UserListDataGrid.SelectedItem;

            NameFormItem.Text = selectedUser.Name;
            AddressFormItem.Text = selectedUser.Address;
            AgeFormItem.Text = selectedUser.Age;
            SexFormItem.Text = selectedUser.Sex;
        }
    }
}
